@@ -1,10 +1,12 @@
-use std::{io, sync::mpsc as sync_mpsc, sync::Arc, thread, time::Duration};
+use std::{
+    io, sync::mpsc as sync_mpsc, sync::Arc, thread, time::Duration, time::Instant,
+};
 
 use log::{error, info};
 use slab::Slab;
 
-use crate::rt::time::{sleep_until, Instant};
 use crate::rt::System;
+use crate::time::{sleep, Millis};
 
 use super::socket::{Listener, SocketAddr};
 use super::worker::{Connection, WorkerClient};
@@ -13,7 +15,7 @@ use super::{Server, ServerStatus, Token};
 const DELTA: usize = 100;
 const NOTIFY: mio::Token = mio::Token(0);
 const ERR_TIMEOUT: Duration = Duration::from_millis(500);
-const ERR_SLEEP_TIMEOUT: Duration = Duration::from_millis(525);
+const ERR_SLEEP_TIMEOUT: Millis = Millis(525);
 
 #[derive(Debug)]
 pub(super) enum Command {
@@ -384,6 +386,7 @@ impl Accept {
                 match self.workers[self.next].send(msg) {
                     Ok(_) => (),
                     Err(tmp) => {
+                        self.update_status(ServerStatus::WorkerFailed);
                         self.srv.worker_faulted(self.workers[self.next].idx);
                         msg = tmp;
                         self.workers.swap_remove(self.next);
@@ -411,6 +414,7 @@ impl Accept {
                         }
                         Err(tmp) => {
                             trace!("Worker failed while processing connection");
+                            self.update_status(ServerStatus::WorkerFailed);
                             self.srv.worker_faulted(self.workers[self.next].idx);
                             msg = tmp;
                             self.workers.swap_remove(self.next);
@@ -457,7 +461,7 @@ impl Accept {
 
                         let notify = self.notify.clone();
                         System::current().arbiter().spawn(Box::pin(async move {
-                            sleep_until(Instant::now() + ERR_SLEEP_TIMEOUT).await;
+                            sleep(ERR_SLEEP_TIMEOUT).await;
                             notify.send(Command::Timer);
                         }));
                         return;
