@@ -1,8 +1,5 @@
-use std::io::{Read, Write};
-use std::time::Duration;
-use std::{io, net, thread};
+use std::{io, io::Read, io::Write, net};
 
-use bytes::Bytes;
 use futures::future::{self, ok, ready, FutureExt};
 use futures::stream::{once, StreamExt};
 use regex::Regex;
@@ -11,17 +8,16 @@ use ntex::http::test::server as test_server;
 use ntex::http::{
     body, header, HttpService, KeepAlive, Method, Request, Response, StatusCode,
 };
-use ntex::rt::time::sleep;
-use ntex::service::fn_service;
-use ntex::web::error;
+use ntex::time::{sleep, Millis};
+use ntex::{service::fn_service, time::Seconds, util::Bytes, web::error};
 
 #[ntex::test]
 async fn test_h1() {
     let srv = test_server(|| {
         HttpService::build()
             .keep_alive(KeepAlive::Disabled)
-            .client_timeout(1000)
-            .disconnect_timeout(1000)
+            .client_timeout(Seconds(1))
+            .disconnect_timeout(Seconds(1))
             .h1(|req: Request| {
                 assert!(req.peer_addr().is_some());
                 future::ok::<_, io::Error>(Response::Ok().finish())
@@ -38,8 +34,8 @@ async fn test_h1_2() {
     let srv = test_server(|| {
         HttpService::build()
             .keep_alive(KeepAlive::Disabled)
-            .client_timeout(1000)
-            .disconnect_timeout(1000)
+            .client_timeout(Seconds(1))
+            .disconnect_timeout(Seconds(1))
             .finish(|req: Request| {
                 assert!(req.peer_addr().is_some());
                 assert_eq!(req.version(), http::Version::HTTP_11);
@@ -61,7 +57,7 @@ async fn test_expect_continue() {
     let srv = test_server(|| {
         HttpService::build()
             .expect(fn_service(|req: Request| async move {
-                sleep(Duration::from_millis(20)).await;
+                sleep(Millis(20)).await;
                 if req.head().uri.query() == Some("yes=") {
                     Ok(req)
                 } else {
@@ -158,7 +154,7 @@ async fn test_chunked_payload() {
 async fn test_slow_request() {
     let srv = test_server(|| {
         HttpService::build()
-            .client_timeout(1)
+            .client_timeout(Seconds(1))
             .finish(|_| future::ok::<_, io::Error>(Response::Ok().finish()))
             .tcp()
     });
@@ -219,7 +215,7 @@ async fn test_http1_keepalive_timeout() {
     let mut data = vec![0; 1024];
     let _ = stream.read(&mut data);
     assert_eq!(&data[..17], b"HTTP/1.1 200 OK\r\n");
-    thread::sleep(Duration::from_millis(1100));
+    sleep(Millis(1100)).await;
 
     let mut data = vec![0; 1024];
     let res = stream.read(&mut data).unwrap();
@@ -529,6 +525,7 @@ async fn test_h1_body_length() {
 
 #[ntex::test]
 async fn test_h1_body_chunked_explicit() {
+    env_logger::init();
     let mut srv = test_server(|| {
         HttpService::build()
             .h1(|_| {
